@@ -4,7 +4,7 @@
 """
 import sys
 
-__version__ = '04.01'
+__version__ = '04.02'
 
 class ShouldBeUnitlessError(TypeError):
     """An operation on a Unum failed because it had units unexpectedly."""
@@ -113,7 +113,7 @@ class Unum(object):
         raises UnumError exception if conv is a unum
                 although unit and value do not represent a basic unit
         """
-        object.__init__(self)
+        object.__init__(self)        
         self._value = value
         self._unit = unit
         if conv is None:
@@ -348,10 +348,30 @@ class Unum(object):
             unit = Unum._NO_UNIT
         return Unum(unit, self._value ** other._value)
 
-    def __cmp__(self, other):
+    def __lt__(self, other):
         s, o = self.matchUnits(Unum.coerceToUnum(other))
-        return cmp(s._value, o._value)
+        return s._value < o._value
 
+    def __le__(self, other):
+        s, o = self.matchUnits(Unum.coerceToUnum(other))
+        return s._value <= o._value
+
+    def __gt__(self, other):
+        s, o = self.matchUnits(Unum.coerceToUnum(other))
+        return s._value > o._value
+
+    def __ge__(self, other):
+        s, o = self.matchUnits(Unum.coerceToUnum(other))
+        return s._value >= o._value
+
+    def __eq__(self, other):
+        s, o = self.matchUnits(Unum.coerceToUnum(other))
+        return s._value == o._value
+
+    def __ne__(self, other):
+        s, o = self.matchUnits(Unum.coerceToUnum(other))
+        return s._value != o._value
+    
     def __abs__(self):
         return Unum(self._unit.copy(), abs(self._value)) 
 
@@ -498,4 +518,4 @@ class Unum(object):
 # Maintain API compatibility with Unum 4 and lower.
 # "as" became a reserved word in 2.5, so we can't use it.
 if sys.version_info < (2, 5):
-    setattr(Unum, "as", Unum.asUnit)
\ No newline at end of file
+    setattr(Unum, "as", Unum.asUnit)
